package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0`````````````"`!(````!``$;P````#0``,4X```!```T`"``
M"``H`!L`&@````8````T``$`-``!`#0```$````!``````4````$`````P``
M`30``0$T``$!-````!,````3````!`````$````!```````!`````0````"T
MG```M)P````%``$```````$``+[T``*^]``"OO0```4T```5=`````<``0``
M`````@``OP@``K\(``*_"````/@```#X````!@````0````$```!2``!`4@`
M`0%(````1````$0````$````!&1TY5$`````````````````````````````
M``8````$9'3E4@``OO0``K[T``*^]````0P```$,````!0````$O;&EB+VQD
M+6QI;G5X+G-O+C(```````0````0`````4=.50```````````@````8````/
M````!````!0````#1TY5``V9PI#OWOE;6L?"F]BC#5\Y["C.````80```',`
M```E```````````````J`````````$P```!H`````````&4````@````6P``
M`$X````>````!0```%4`````````,0```%P```!P````"P```"<````7````
M;````$L```````````````X```!#````'```````````````$`````,````Z
M`````@````````!I````-@````````!*`````````&8`````````8```````
M```9````#```````````````,P```%X`````````7P``````````````00``
M`#4````*````;P``````````````1@`````````6```````````````A````
M`````%T````H````#P````8````D````+```````````````+@```&$````W
M````3P```$<````^````:P````````!6````````````````````,`````@`
M````````'0```%(````B````*P```&(````C````````````````````,@``
M````````````/``````````[`````````!L`````````.0``````````````
M`````#@``````````````%D```!J`````````%H````T````````````````
M`````````&T```````````````````!(````````````````````$@``````
M```]`````````$T`````````#0```%,`````````5```````````````````
M```````5```````````````!````+0```&X`````````%````%$`````````
M````````````````0@`````````1`````````!,```!C``````````````!8
M```````````````)````!``````````O````'P```!@```!%````4```````
M````````!P````````!7````<0```$0`````````````````````````````
M``````!R````9````!H````F`````````"D``````````````#\```!)````
M``````````!`````````````````````9P```````````````````&$````#
M````(`````H(`!*@H!%&`@@``(`8$0!6/``(PA$5``T"$``````H```````@
M(E@```H$"J`'A$1@10A``80`29<\0CX(``$`)(!0(8$,8`A:0$EX0`!`(D(`
M`0``0``9`(3`C!"0$`((``&"B9`0`4'"0$"80"R`(`!```D$(`#D`92`P':7
MC@````,`````````!`````4````'````"`````````````````````D````+
M````#0````X`````````#P```!$````5`````````!8``````````````!<`
M```:````&P```!\````@````(0```",`````````)````"4````H````````
M`"D````J````*P```"P````M`````````"X`````````,@```#,`````````
M-P``````````````.````#H````[`````````#P````]````/P```$(```!%
M`````````$@```!)````2@```$L```````````````````!-````````````
M`````````````$\```!0`````````%(`````````4P```%4`````````5P``
M`%@``````````````%D```!=`````````%\`````````80````````!D````
M9@````````!H````:0```&H```!L````;0```'`<DY9?D.]:H_^'CL(<D]M7
M"Y<Z#3HS[$>$!%'2#8)T@6M*\'K%CD%]KPP_S2#.(_<"L'0@?-1DU2AW4N!F
MS*]F]CU.+EX`]]O_AZ0'YYU(L0H"I^#_KDK.+4?>SP'&1^,]X`[&Q85S;`*0
M/^Q\EGX_WDYO-9`%B<4B24EF$N^88:3Y(P$<D[N=9VB2H(&<^8;LU45##SN:
M6WR=34&$,(1QUNM5+6NCW:>O90"CGN(4#!GV`J*>X\W:A:4R!6!LH?OMVV(R
M#N_3ZA]`.<@.\8VYPL/[Z?]](DH<D][MP.-+K1Q8<=DBX=`K<[$.++W6GQM9
MR19@'T`[6"P_Y<-HU"*8?)+CN@[D_R'Z:7INPMV8BE<UV8MB!*V3P?#C-\CO
M\D-/((7>&'SHFQ4BZ][):%I/0)RYQ0V"N#!??1M1;XL!LW#C;W9]2]"]UD,)
M:JC'(I^0!ZE341`"'9N<J7Z"^M!BB_8L['R:?VM\EO"&_"R?T?E1"^X=T]OS
MHC#_Y@V"=9`02V9#8'9?7LVR;`7Q6NH6#3FM/:@-_"E)^^"C&,17XE):DE</
M[]+]2/[?+!_?Q6[I$)!]MIO%+G&RU<B?RJO?````````````````````````
M`!$``````````"`````````@```````````@```````$00`"P[P`````$@``
M`````PD``L#X`````!(```````.-``+`7``````2```````#J0`"PJ@`````
M$@``````!38``L04`````"```!<```5U``+$(`````01```7```">@`"P(P`
M````$@```````X8``L-0`````!(```````)J``+!Z``````2```````%60`!
M,B0```!$$@``#0```T8``L-<`````!(```````-Q``+"2``````2```````#
MW@`"P,@`````$@``````!+@``4YP```$4!(```T```"Q``+`4``````2````
M```$\@`!/2P```&T$@``#0``!$@``L%``````!(```````-7``+"A``````2
M```````#]@`"PFP`````$@```````5```L-$`````!(```````3<``$VM```
M`-P2```-```%$``"PE0`````$@``````!80``41L```*!!(```T```2;``$=
M`````%02```-```#?@`"P+``````$@```````\L``L&@`````!(```````)#
M``+#C``````2```````#00`"P^``````$@```````8```L#@`````!(`````
M``1;``+$*`````0A```8```#Z``"P=P`````$@```````O$``L-H`````!(`
M``````+X``+`1``````2```````#FP`"PCP`````$@```````8T``L"\````
M`!(```````"@``+!]``````2```````$<@`"Q"@`````$`#_\0```NL``L*0
M`````!(```````,1``+!9``````2```````!'0`"PW0`````$@```````?X`
M`L,L`````!(```````1<``+$*`````0A```8````[``"PO``````$@``````
M!*@``5/`````"!(```T```(<``+!'``````2```````%20`!4^````!T$@``
M#0```DX``L*<`````!(```````61``$Y[````3`2```-```%.@`!&\`````X
M$@``#0``!+(``53``````!(```X```-@``+"S``````2```````%0P`!&V0`
M````$@``#````-<``L,@`````!(```````.]``+`@``````2```````#E``"
MPN0`````$@```````R```538````!!$```\```1Y``+$*``````0`/_Q```$
M&@`"PA@`````$@```````#0``L'0`````!(```````0R``+#%``````2````
M```%)0`"Q"0````$$0``%P```5T``L(``````!(```````5!``%2P````#@2
M```-```!H0`"P'0`````$@``````!(4``M1H`````!``__$```6C``%"````
M`FP2```-```#+P`"P.P`````$@```````/T``L$0`````!(```````!X``+#
M^``````2```````"UP`"P5@`````$@```````EP``L)X`````!(```````$+
M``+$!``````2```````!00`"PF``````$@```````&,``L.P`````!(`````
M``'J``+!?``````2````````0@`"POP`````$@``````!%H``L0H````!!$`
M`!@```.B``+!*``````2```````!R@`"P30`````$@``````!,X``3!@````
M<!(```T```/6``+!Q``````2````````R``"P@P`````$@``````!30``L04
M`````!```!<```0D``+#@``````2```````!;@`"P-0`````$@```````(\`
M`L/(`````!(```````3^``$]!````"@2```-```"F``"P7``````$@``````
M`H4``L,X`````!(```````15``$_2````K@2```-```!I@`"P8@`````$@``
M````!`8``L(P`````!(```````/]``+#"``````2```````"HP`"Q#`````3
M$0``&```!7H``5BX``!;VA$```\```.V``+")``````2```````#L``"PM@`
M````$@```````2\``L&X`````!(```````-.``+#U``````2```````$.@`"
MP:P`````$@```````I$``L*T`````!(```````'8``+#I``````2```````%
ML``!.QP```'H$@``#0``!`T``L%,`````!(```````&K``+"P``````2````
M```#>``"P&@`````$@```````BP``L$$`````!(```````49``$^X````&@2
M```-````5``"PY@`````$@``````!(H``3>0````%!(```T```&W``+`F```
M```2```````"-0`"P90`````$@````!L:6)P97)L+G-O+C4N,3``7U]G;6]N
M7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E
M<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA
M9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T
M<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R
M;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R
M7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O
M<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E
M<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R
M`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!0
M97)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!0
M97)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E
M<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U
M;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L
M7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O
M+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I
M9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A
M9`!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`
M97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A
M:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T;VL`
M<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`;65M8W!Y`%]?<W1R;F-P>5]C
M:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?;&]C
M`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`')E861D:7(V
M-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B
M<W-?<W1A<G0`7V5N9`!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?
M7VQI8F-?8W-U7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?
M8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U
M<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'-I>F5?;&]A9%]M
M95\R`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!84U])
M;G1E<FYA;'-?4$%27T-,14%24U1!0TL`;F%M95]L;V%D7VUE7S(`<&%R7VUK
M=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,P!'3$E"0U\R+C,N,@!'3$E"0U\R
M+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP`````````````P`'``,``P`!``$`
M```#`````0`#``,`!0`!`````0`#``,``P````$``P`!``$``P`%`````P``
M``,`"``'``(``P```````0`"``(```````,````!`````0````$``0`!``D`
M`0````0``P`!``$`!0````,``0````$````!``$`!@```````@``````````
M```````#``,````!``,````!``D```````$```````$``P`#``,````!``,`
M`P````,``P`#`````0`$`````P````$````!```````!``8```,6````$```
M`'`-:6D4````"0``!;T````0#6EI$P````@```7'````$`EI&7(````&```%
MT0```!`-:6D2````!0``!=T````0"6D9=`````0```7G````$`UI:1`````#
M```%\P```````0`"```"QP```!``````#6EI$@````<```7=````$`UI:1``
M```"```%\P```````L`$```!%````````L0H``!/$P```````L0P``!@$P``
M`````L!$```C%0```````L!0```1%0```````L!<```%%0```````L!H``!L
M%0```````L!T``!"%0```````L"````X%0```````L",```)%0```````L"8
M``!Q%0```````L"D```!%0```````L"P```;%0```````L"\```E%0``````
M`L#(```/%0```````L#4``!7%0```````L#@```?%0```````L#L``!%%0``
M`````L#X```$%0```````L$$``!M%0```````L$0``!&%0```````L$<```O
M%0```````L$H``!0%0```````L$T``!1%0```````L%````3%0```````L%,
M``!J%0```````L%8``!(%0```````L%D```I%0```````L%P``!:%0``````
M`L%\``!-%0```````L&(``!=%0```````L&4``!R%0```````L&@```<%0``
M`````L&L``!F%0```````L&X``!D%0```````L'$``!3%0```````L'0```]
M%0```````L'<```A%0```````L'H```+%0```````L'T```F%0```````L(`
M``!`%0```````L(,``!4%0```````L(8```\%0```````L(D``!B%0``````
M`L(P``!>%0```````L(\```D%0```````L)(```.%0```````L)4```8%0``
M`````L)@``!+%0```````L)L```5%0```````L)X``!)%0```````L*$```4
M%0```````L*0```H%0```````L*<```Q%0```````L*H```&%0```````L*T
M``!G%0```````L+```!K%0```````L+,```U%0```````L+8``!C%0``````
M`L+D```Y%0```````L+P```M%0```````L+\``!.%0```````L,(``!?%0``
M`````L,4```^%0```````L,@```W%0```````L,L```K%0```````L,X``!;
M%0```````L-$```6%0```````L-0```*%0```````L-<```-%0```````L-H
M```B%0```````L-T```J%0```````L.```!6%0```````L.,```=%0``````
M`L.8``!O%0```````L.D``!H%0```````L.P``!,%0```````L.\```#%0``
M`````L/(``!8%0```````L/4``!E%0```````L/@```>%0```````L/L```V
M%0```````L/X``!'%0```````L0$``!*%0````"!P^`(K@/`%YWCOZ`O``!I
M?____*X%X)0#````@A!@!,(%P`&`H&```H``!`$```!``&E&`0```$```$,!
M````0``.,0$```"!Q^`(@>@`````````````````````````````O!```)PC
MH!C2`Z!8E`.@7!$``$\7``!4&0``5)`2(TB6$N/@F!,CP)H0``%``&E5`0``
M`````````````````)WCOZ`G``"QP@S@1("@8``20``:)0``KR,``*^D%*+\
MHA1C`*(D0!(A``"QHSQ@`L($($BB!'__@*!`$3I```Z"$"`!H!0@2((`8`'"
M)```@RA@`L($@`&?P$```0```,($``"`H$`1"D__^8(`8`&"$"`!PBS@1('/
MX`@!````G>._H('/X`@!````,&@`!0$````!`````0````$```"=X[^@$0``
MK\("(P2`H&```D``"9`2(P0#````@A!@`("@8``"0``$`0```)_`0``!````
M@<_@"`$````!````G>._H('/X`@!````,&@`!0$````!`````0````$```"=
MX[^@Q`X``,).``"`H&```D``#X80`!@#``!6R`!@E((&(`':20``A2B@&(4X
MH!B`H(`-AV1``<0(0`")**`8@*$@`!)/__F"`&`!@<_@")`0``.=X[Y@B`8@
M'((0(`"&![[`Q`$``<0@P`&"`&`$@*!@0#)/__W$`0`!@@>^](@'O_3&`'_L
MQ`!``(08P`+&`'_4A!B``\8`?\R$&(`#AS"@'X0`@`*$$,`"Q"!@#((`8`2`
MH$`$,D__],8`?^S$!@``U@8@!,8&(`C(!B`,V`8@$,('OL"8`P`!`Q:@GH(0
M89F8`P`!E3"@&YLHH`6:$H`-F`,`#90I``N:",`+FA*`#9H#``V9,N`"ERK@
M'I82P`S8![[$B`$`#)@!``&4*,`"B`K``H@2@`28`P`$E3-@&XDK8`6($H`$
MB`,`!)4PH`*9**`>F!,`"M0'OLB&`,`*E`#``9,Q(!N'*2`%AA)``Y0"@`.2
M*L`-A@M`#(820`.&`H`#DS-@`I4K8!Z4$H`)V@>^S)H#0`&6`T`+DBL`!)H)
M``J:$D`-E@+`#9,PX!N;*.`%FA)`#9H"P`V3,2`"ERD@'I82P`G(![[0B`$`
M`9@!``R3,V`;B2M@!8@20`28`P`$DBJ``X@(P`N($D`$B`,`!),PX`*9*.`>
MF!,`"<8'OM2&`,`!E`#`"I(JP`V&"T`,AA)``Y0"@`.3,2`;ARD@!8820`.&
M`H`#DS-@`I4K8!Z4$H`)V@>^V)H#0`&6`T`+DS#@&YLHX`6:$D`-E@+`#9(K
M``2:"0`*FA)`#9H"P`V3,2`"ERD@'I82P`G(![[<B`$``9@!``R2*H`#B`C`
M"X@20`28`P`$DS-@&XDK8`6($D`$B`,`!),PX`*9*.`>F!,`"<8'ON"&`,`!
ME`#`"I,Q(!N'*2`%AA)``Y0"@`.2*L`-A@M`#(820`.&`H`#DS-@`I4K8!Z4
M$H`)V@>^Y)H#0`&6`T`+DBL`!)H)``J:$D`-E@+`#9,PX!N;*.`%FA)`#9H"
MP`V3,2`"ERD@'I82P`G(![[HB`$``9@!``R3,V`;B2M@!8@20`28`P`$DBJ`
M`X@(P`N($D`$B`,`!),PX`*9*.`>F!,`"<8'ONR&`,`!E`#`"I(JP`V&"T`,
MAA)``Y0"@`.3,2`;ARD@!8820`.&`H`#DS-@`I4K8!Z4$H`)V@>^\)H#0`&6
M`T`+DS#@&YLHX`6:$D`-E@+`#9(K``2:"0`*FA)`#9H"P`V3,2`"ERD@'I82
MP`G(![[TB`$``9@!``R2*H`#B`C`"X@20`28`P`$DS-@&XDK8`6($D`$B`,`
M!),PX`*9*.`>F!,`"<8'OOB&`,`!E`#`"I,Q(!N'*2`%AA)``Y0"@`.2*L`-
MA@M`#(820`.&`H`#DS-@`I4K8!Z4$H`)V@>^_)H#0`&6`T`+DBL`!)H)``J:
M$D`-E@+`#9,PX!N;*.`%FA)`#9H"P`V3,2`"ERD@'I82P`G(![\`B`$``9@!
M``R3,V`;B2M@!8@20`28`P`$DBJ``X@(P`N($D`$B`,`!),PX`*9*.`>F!,`
M"<8'OP2&`,`!E`#`"I(JP`V&"T`,AA)``Y0"@`.3,2`;ARD@!8820`.&`H`#
MDS-@`I4K8!Z4$H`)V@>_")H#0`&6`T`+DS#@&YLHX`6:$D`-E@+`#9(K``2:
M"0`*FA)`#9H"P`V3,2`"ERD@'I82P`G(![\,@@$``8@`0`R8*H`#@@C`"X(3
M``&(`0`!F3-@&X,K8`6"$P`!B`$``8,PX`*9*.`>F!,``0,;MGJ"$&.AQ@>_
M$(8`P`&4`,`*AAL`"X88P`V4`H`#DS$@&X<I(`6&$D`#A@*``Y4S8`*;*V`>
MFA-`"M0'OQ24`H`!E@*`"Y0;0`R4&H`$E`+`"I,PX!N7*.`%EA)`"Y8"@`N5
M,2`"B2D@'H@1``K4![\8E`*``9@"@`R4&0`-E!J``Y0#``J3,N`;F2K@!9@2
M0`R8`H`,E3#@`H<HX!Z&$,`*U`>_')0"@`&:`H`-E!C`!)0:@`N4`T`*DS,@
M&YLK(`6:$D`-F@*`#94RX`*7*N`>EA+`"M0'OR"4`H`!B`*`!)0:P`.4&H`,
ME`$`"I,S8!N)*V`%B!)`!(@"@`25,R`"F2L@'I@3``K4![\DE`*``88"@`.4
M&P`+E!J`#90`P`J3,2`;ARD@!8820`.&`H`#E3-@`ILK8!Z:$T`*U`>_*)0"
M@`&6`H`+E!M`#)0:@`24`L`*DS#@&Y<HX`66$D`+E@*`"Y4Q(`*)*2`>B!$`
M"M0'ORR4`H`!F`*`#)09``V4&H`#E`,`"I,RX!N9*N`%F!)`#)@"@`R5,.`"
MARC@'H80P`K4![\PE`*``9H"@`V4&,`$E!J`"Y0#0`J3,R`;FRL@!9H20`V:
M`H`-E3+@`I<JX!Z6$L`*U`>_-)0"@`&(`H`$E!K``Y0:@`R4`0`*DS-@&XDK
M8`6($D`$B`*`!)4S(`*9*R`>F!,`"M0'OSB4`H`!A@*``Y0;``N4&H`-E`#`
M"I,Q(!N'*2`%AA)``X8"@`.5,V`"FRM@'IH30`K4![\\E`*``98"@`N4&T`,
ME!J`!)0"P`J3,.`;ERC@!9820`N6`H`+E3$@`HDI(!Z($0`*U`>_0)0"@`&8
M`H`,E!D`#90:@`.4`P`*DS+@&YDJX`68$D`,F`*`#)4PX`*'*.`>AA#`"M0'
MOT24`H`!F@*`#908P`24&H`+E`-`"I,S(!N;*R`%FA)`#9H"@`V5,N`"ERK@
M'I82P`K4![](E`*``8@"@`24&L`#E!J`#)0!``J3,V`;B2M@!8@20`2(`H`$
ME3,@`IDK(!Z8$P`*U`>_3)0"@`&&`H`#E!L`"Y0:@`V4`,`*DS$@&X<I(`6&
M$D`#A@*``Y4S8`*;*V`>FA-`"M0'OU"4`H`!E@*`"Y0;0`R4&H`$E`+`"I,P
MX!N7*.`%EA)`"Y8"@`N5,2`"B2D@'H@1``K4![]4E`*``9@"@`R4&0`-E!J`
M`Y0#``J3,N`;F2K@!9@20`R8`H`,E3#@`H<HX!Z&$,`*U`>_6)0"@`&:`H`-
ME!C`!)0:@`N4`T`*DS,@&YLK(`6:$D`-F@*`#94RX`*7*N`>EA+`"M0'OUR"
M`H`!B`!`!((:P`."&$`,B`$``94S8!N#*V`%@A*``8@!``&#,R`"F2L@'I@3
M``$#(\;O@A!@W-0'OV"4`H`!A@*``Y(3``N2"D`-E`L`"Y020`J4`,`*DS$@
M&X<I(`6&$D`#A@*``Y4S8`*;*V`>FA-`"M0'OV24`H`!E@*`"Y(30`R2"D`$
ME`M`#)020`J4`L`*DS#@&Y<HX`66$D`+E@*`"Y4Q(`*)*2`>B!$`"M0'OVB4
M`H`!F`*`#)(1``V2"D`#E`D`#9020`J4`P`*DS+@&YDJX`68$D`,F`*`#)4P
MX`*'*.`>AA#`"M0'OVR4`H`!F@*`#9(0P`22"D`+E`C`!)020`J4`T`*DS,@
M&YLK(`6:$D`-F@*`#94RX`*7*N`>EA+`"M0'OW"4`H`!B`*`!)(2P`.2"D`,
ME`K``Y020`J4`0`*DS-@&XDK8`6($D`$B`*`!)4S(`*9*R`>F!,`"M0'OW24
M`H`!A@*``Y(3``N2"D`-E`L`"Y020`J4`,`*DS$@&X<I(`6&$D`#A@*``Y4S
M8`*;*V`>FA-`"M0'OWB4`H`!E@*`"Y(30`R2"D`$E`M`#)020`J4`L`*DS#@
M&Y<HX`66$D`+E@*`"Y4Q(`*)*2`>B!$`"M0'OWR4`H`!F`*`#)(1``V2"D`#
ME`D`#9020`J4`P`*DS+@&YDJX`68$D`,F`*`#)4PX`*'*.`>AA#`"M0'OX"4
M`H`!F@*`#9(0P`22"D`+E`C`!)020`J4`T`*DS,@&YLK(`6:$D`-F@*`#94R
MX`*7*N`>EA+`"M0'OX24`H`!B`*`!)(2P`.2"D`,E`K``Y020`J4`0`*DS-@
M&XDK8`6($D`$B`*`!)4S(`*9*R`>F!,`"M0'OXB4`H`!A@*``Y(3``N2"D`-
ME`L`"Y020`J4`,`*DS$@&X<I(`6&$D`#A@*``Y4S8`*;*V`>FA-`"M0'OXR4
M`H`!E@*`"Y(30`R2"D`$E`M`#)020`J4`L`*DS#@&Y<HX`66$D`+E@*`"Y4Q
M(`*)*2`>B!$`"M0'OY"4`H`!F`*`#)(1``V2"D`#E`D`#9020`J4`P`*DS+@
M&YDJX`68$D`,F`*`#)4PX`*'*.`>AA#`"M0'OY24`H`!F@*`#9(0P`22"D`+
ME`C`!)020`J4`T`*DS,@&YLK(`6:$D`-F@*`#94RX`*7*N`>EA+`"M0'OYB4
M`H`!B`*`!)(2P`.2"D`,E`K``Y020`J4`0`*DS-@&XDK8`6($D`$B`*`!)4S
M(`*9*R`>F!,`"M0'OYR4`H`!A@*``Y(3``N2"D`-E`L`"Y020`J4`,`*DS$@
M&X<I(`6&$D`#A@*``Y4S8`*;*V`>FA-`"M0'OZ"4`H`!E@*`"Y(30`R2"D`$
ME`M`#)020`J4`L`*DS#@&Y<HX`66$D`+E`*`"Y<Q(`*)*2`>B!$`"]8'OZ26
M`L`!F`+`#)(1``V2"D`#E@D`#9820`N6`P`+DS*@&YDJH`68$D`,F`+`#)<P
MX`*'*.`>AA#`"]8'OZB6`L`!F@+`#9(0P`22"D`*E@C`!)820`N6`T`+DS,@
M&YLK(`6:$D`-E@+`#9,RH`*;*J`>FA-`"=0'OZR"`H`!B`!`!)030`.4"H`,
M@@M``X(2@`&4`0`!B3+@&X,JX`6"$0`!E`*``8,S(`*)*R`>B!$``0,RF+""
M$&'6V`>_L((#``&&`$`#@AD`#8(80`N&`,`!F3*@&X,JH`6"$P`!A@#``8,R
MX`*7*N`>EA+``0,RF+""$&'6V`>_M)@#``&:`P`-F!K`!)@;``J8`T`,DS#@
M&YLHX`6:$D`-F`,`#9,RH`*;*J`>FA-`"=0'O[B4`H`!B`*`!)0;0`N4&H`#
ME`$`"I,S(!N)*R`%B!)`!(@"@`25,.`"ARC@'H80P`K4![^\E`*``98"@`N4
M&,`-E!J`#)0"P`J3,2`;ERD@!9820`N6`H`+E3,@`IDK(!Z8$P`*U`>_P)0"
M@`&:`H`-E!L``Y0:@`24`T`*DS+@&YLJX`6:$D`-F@*`#94Q(`*)*2`>B!$`
M"M0'O\24`H`!A@*``Y09``R4&H`+E`#`"I,S8!N'*V`%AA)``X8"@`.5,N`"
MERK@'I82P`K4![_(E`*``9@"@`R4&L`$E!J`#90#``J3,.`;F2C@!9@20`R8
M`H`,E3-@`ILK8!Z:$T`*U`>_S)0"@`&(`H`$E!M`"Y0:@`.4`0`*DS,@&XDK
M(`6($D`$B`*`!)4PX`*'*.`>AA#`"M0'O]"4`H`!E@*`"Y08P`V4&H`,E`+`
M"I,Q(!N7*2`%EA)`"Y8"@`N5,R`"F2L@'I@3``K4![_4E`*``9H"@`V4&P`#
ME!J`!)0#0`J3,N`;FRK@!9H20`V:`H`-E3$@`HDI(!Z($0`*U`>_V)0"@`&&
M`H`#E!D`#)0:@`N4`,`*DS-@&X<K8`6&$D`#A@*``Y4RX`*7*N`>EA+`"M0'
MO]R4`H`!F`*`#)0:P`24&H`-E`,`"I,PX!N9*.`%F!)`#)@"@`R5,V`"FRM@
M'IH30`K4![_@E`*``8@"@`24&T`+E!J``Y0!``J3,R`;B2L@!8@20`2(`H`$
ME3#@`H<HX!Z&$,`*U`>_Y)0"@`&6`H`+E!C`#90:@`R4`L`*DS$@&Y<I(`66
M$D`+E@*`"Y4S(`*9*R`>F!,`"M0'O^B4`H`!F@*`#90;``.4&H`$E`-`"I,R
MX!N;*N`%FA)`#9H"@`V5,2`"B2D@'H@1``K4![_LE`*``88"@`.4&0`,E!J`
M"Y0`P`J3,V`;ARM@!8820`.&`H`#E3+@`I<JX!Z6$L`*U`>_\)0"@`&8`H`,
ME!K`!)0:@`V4`P`*DS#@&YDHX`68$D`,F`*`#)4S8`*;*V`>FA-`"M0'O_24
M`H`!B`*`!)0;0`N4&H`#E`$`"I,S(!N)*R`%B!)`!(@"@`25,.`"ARC@'H80
MP`K4![_XE`*``98"@`N4&,`-E!J`#)0"P`J3,2`;ERD@!9820`N6`H`+E3,@
M`IDK(!Z8$P`*U`>__(0`@`J"`(`!A`!`#8(;``."&$`$A`"``9LRX!N#*N`%
M@A-``8(`@`'")@``P@8@!)8`0`O6)B`$@S$@`HDI(!Z"$$`$Q`8@"((`@`'"
M)B`(P@8@#)@`0`S8)B`,P@8@$(8`0`/&)B`0@<_@"`$```"=X[^@@*8@``)(
M`#,#``"QZ`!@*("E(``"2``O`0```,).``"`H``!A$`@`((88#V`H``!@D`@
M`("(@`$"2``,I!``&*0$H`'"3(``@*```81`(`""&&`]@*```8)`(`"`B(`!
M,D__^:0$H`'@!0``@*0@``)``!BD)(`8HA``%)`0`!"2$``80`!DVI00`!*`
MHB``,D``#*($8`3"3``2@*!@/3)(``BB!&`$HB1`%*,\8`+B)D``I@2@`8''
MX`B1[``3X`1``("D(``23__ND!``$('/X`B0$"``G>._F)`0`!A____'D@>_
M_(''X`B1Z``(G>._H`,``+'"`&`<@*!__Q)(`!8#``"Q$0``57____.0$B#@
M@*(@`")```V$$"``PDH``("@8``"2``(Q`H``(4HH!B%.*`8A!B@,("@``(0
M:``#A$`@`(00(``#``"QQ"!@'`,``+&!S^`(T`!@')WCOYB@![_\(P``L1!H
M``JB%&`H@RA@`L0$0`""`(`!@@!@!,0`0`"`H*``$D?__<0@?_R0$``8?___
MF9(0`!"`HB``$D__],('O_R!S^`(`0```)WCL`"<`[^8P@'@%,(GO_R"$"``
M$0``59`2(/`3/__[DA)C^)('@`E``&1OE!`O_X"B(``$0``B@@(__P4___N$
M$*/XA`>``L1(@`&`H*``$D@`!J`0``B`H&``!$``&*`0``&0$``!$3__^Y`2
M(_B0!X`(DA`@+T``9&V4$``0@*(@``)```X!````0`!D?9`0(`!``&/HT`(`
M`)(0`!D5/__[E!*C^)0'@`I``&0DEA``$!!H``D!````0`!D<9`0(`!``&/<
MT`(``)(0`!E``&/0E!``&L0'O_S"`>`4A)B``8(0(``"2``$`0```$``9"X!
M````@<_@"`$```"=X[^@0`!D7Y`0(`!``&/*T`(``$``8]>2$#__0`!D69`0
M(`!``&/$T`(``!,``$R2$F)H0`!D:)00(`"!S^`(`0```)WCOZ!``&1.D!`@
M`$``8[G0`@``0`!C=0$```#"`@``X`!@!$``9$:0$"``0`!CL=`"``!``&..
M`0```,(*``#"+"`80`!D/I`0(`!``&.IT`(``$``8V4!````P@(``.``8`1`
M`&0VD!`@`$``8Z'0`@``0`!C@0$```#"`@``P@!@$(,P8!?"-"`:0`!D+)`0
M(`!``&.7T`(``$``8U,!````P@(``.``8`1``&0DD!`@`$``8X_0`@``$P``
M59(288!``&0&E!`@`-`D(!Q``&0;D!`@`$``8X;0`@``0`!C0@$```#"`@``
MX`!@!$``9!.0$"``0`!C?M`"``!``&-5`0```,("``#")"`@0`!D"Y`0(`!`
M`&-VT`(``$``8S(!````P@(``.``8`1``&0#D!`@`$``8V[0`@``0`!CT@$`
M``#$`@``@*"@``)```J"$"``0`!C^9`0(`!``&-DT`(``$``8\@!````P@(`
M`,(`8&S")"`D0`!C\)`0(`!``&-;T`(``$``8Q<!````P@(``,(`8`3`(&`H
M0`!CYY`0(`!``&-2T`(``$``8PX!````P@(``,(`8`3`(&`L0`!CWI`0(`!`
M`&-)T`(``$``8P4!````P@(``.``8`1``&/6D!`@`$``8T'0`@``0`!CQ@$`
M``#"`@``PB0@,('/X`@!````G>._.("F(``"0`!=`0```,).``"`H&```D@`
M60$```!``&-,D!``&("B(``22`!"I!``"('/X`@!````@@0@$\0(0`#&#$``
M@*"``S)(``C&#,``R`A@`<8,8`&`H0`#`D@`/@$```#&#,``@*"``Q)(``P!
M````Q@A@`<0,X`&`H,`"$D@`!P$```#$"&`"P@S@`H"@@`$"2``P`0```$``
M8TJ0$``8N!``"+H$(!-``&-&D!``'9`'``A``&-AD`(@`J`0``B2$"`!E!`_
M_Y80`!28$``80`!CC9H0`!V0$"`#DA``$$``8MN4$``5@*(__P)```K"![^H
M@@A`%H"@0!<22``&`0```'___[V0$``0$&@`!`$```!``&,ND!``$$``8OR0
M$``0$&@`"P$````C``!5HA1A`"<``%6F%.$(*0``5:@5(1"J![^8+0``/"\`
M`!!``&,3D!``$H"B(``23_^VH!``"$``8RF0$``20`!C/)`0`!B!S^`(`0``
M`)WCOZ!``&-JD!`@`$``8M70`@``0`!C/`$```"4$``(D!`@`T``8N&2$``8
M@*(@`!)(`"$!````0`!C70$```!``&+(T`(``$``8R\!````Q`(@$`,``#R$
M"(`!`P``$("@@`$B0``/D!``&$``8U"0$"``0`!BN]`"``!``&,B`0```,0"
M(!`#```\A`B``0,``"B`H(`!$D@`!Y`0`!A``&+%DA`@`H"@``B!S^`(D&`_
M_X'/X`B0$"```S__]X(08Y"=XX`!P@'@%,(GO_R"$"``0`!B9"$___N8$``(
MH!0C^*`'@!"0$``0DA`@`14```24$J`!%P``5982X1@;``!50`!C(9H382B`
MHB``!D@`&+`0(`"0$``0$S__]Y(28_"2!X`)0`!B^A4```2`HB``!D@`#J`0
M``A``&+@D`(@`8"B(``"0``*L!``"!,___>2$F/PD@>`"4``8K24$``0$&@`
M`\`N`!"P$"``Q`>__,(!X!2$F(`!@A`@``)(``0!````0`!BTP$```"!S^`(
M`0```)WCOZ!____(`0```(''X`B1Z``(G>._F,).0`""&&`]@*```;)F?_]`
M`&*AD!``&:00``B0$``8?__]Z9('O_R`HB```D``$*`0``A``&*8`0```("D
M@`@X0``ZPDX``((0(`#$#D`!Q"P``84HH!B`H*``$D___((`8`&!S^`(D!`@
M``,``+'0`&`HQ`(``((0``B`H*```D``!Z`0(`""`&`$Q`!``("@H``23__]
MH`0@`0,``+'"`&!0@*!@``)(``N$$"`!D@0@`D``8A63*F`"`P``L8"B(``"
M2`!=T"!@*!!H`!&"!"`!`P``L<0@8%"0!"`"0`!BBY$J(`*`HB```D@`4Z80
M``@C``"QHA1@*-($0`!``&*;E2P@`N8D0`""!"`!!0``L<0`H"B#*&`"P""`
M`>`GO_S"3@``@*```89`(`""&&`]@*```81`(`"`B,`"`D``#((0`!B"`&`!
MQ$A``("@``*&0"``A!B@/8"@``*$0"``@(C``C)/__F"`&`!Q`>__(4HH`('
M``"QX`#@**`$``*0!*`"@B!`&$``8F"0`@`!@*(@``)``"C0)````P``L<0`
M8"C"![_\@RA@`L(`@`'$#@``ARB@&("@X``"0``2Q"A``(4XX!B`H*`]`D``
M#X00(#VP!B`!@@!@`<0.``#$*$``ARB@&("@X``"0``&L`8@`84XX!B`H*`]
M,D__^((`8`&$$"`]Q"A``(00(`#&#D`"B`!``L8I(`&'*.`8@*#@`!)/__N$
M`*`!@<_@")`0(`"P$#__@<_@"`$```"=X[^`(0``5:`4(3#@)[_H`P``58(0
M84#")[_L`P``58(084C")[_P`P``58(085#")[_T`P``58(085C")[_X`P``
M58(088#")[_\PDP``("@8``"0``U`P``5N@`8)BF![_L*P``5:H587!___U\
MD!``$("B(``"0``&HA``",)*``"`H&``$D@`!P$```"0$``0?___29(0`!@0
M:``?X`3``$``8@:2$``8@*(@`#)(`!K@!,``0`!AYI`0`!BL$``(0`!AXY`0
M`!2D$``(0`!AX)`0`!&D!8`2I`2@`D``8?J0!(`(I!``".(CH%R2$"`!E!`_
M_Y80`!68$``80`!B)9H0`!20$``0?___*Y(0`!+@!,``PDP``("@8``23__3
MI@3@!('/X`@!````G>._>,(!X!3")[_\@A`@``,``%:"$&!PQ!A``,0_O]C$
M&&`(Q#^_X,088!#$/[_HQ!A@&,0_O_#"$&`@PC>_^!$``%5___U<D!(A>!$`
M`%5___U9D!(AB!$``%5___U6D!(AD!$``%5___U3D!(AH!$``%5___U0D!(A
MJ!$``%5___U-D!(AN!$``%5___U*D!(AR!$``%5___U'D!(@X!$``%5___U$
MD!(AV!$``%5___U!D!(AZ!$``%5___T^D!(A^!$``%5___T[D!(B"!$``%5_
M__TXD!(B&!$``%5___T3D!(B*("B(``"0``%DA``"!$``%5___[DD!(AV!$`
M`%5___T*D!(B0("B(``"0``%DA``"!$``%5___[;D!(B6!$``%5___T!D!(B
M:("B(``"0``'DA``"!$``%5___[2D!(AR!!H`!H1``!5$0``57___/:0$B)X
M@*(@``)```>2$``($0``57___L>0$B#@$&@`#Q$``%60![_I$P``59(28I!`
M`&&NE!`@"H"B(``22``'$0``51$``%60$B#@?__^N9('O_,1``!5D!(AJ!,`
M`%5___ZTDA)BH,0'O_S"`>`4A)B``8(0(``"2``$`0```$``878!````@<_@
M"`$```"=X[^@0`!A6;`0(`!``&%1`0```("B(``R2``"\`(``('/X`@!````
MG>._H("F(``"0``&H!``&,).``"`H&``$D@`#`$```!``&%:D!`@`H"B(``"
M0``%L!``"((0("["*@``P"H@`8'/X`@!````0`!A,I`0`!B4`C__E`8`"H"F
M``H:0``?`P``5L(`8)3(2H``Q`A``,)(0`"`H0`!$D``#L8*@`"'*.`8ASC@
M&)0"O_^`I``*&D``$X"B@!#"2H``@*!``R)/__N4`K__$&@`/,9*@`"%**`8
MA3B@&)0"O_^`I``*&D``!X"B@!#"2H``@*!``C)/__N4`K__@**`$!)``!8#
M``!6T`!@E,1*@`#"2@``@*"``1)(``P!````0`!A(Y`0(`*`HB```D?_SK`0
M``B"$"`NPBH``,`J(`&!S^`(`0```$``86$!````@<?@")'H``C&`&"4E`*_
M_X"D``HZ0``(E"*`$,1*@`#"2,``@*"``2)/__J4`K__E"*`$(0"H`(#```$
M@*"``1A/_[6P$"``(P``L9`48%B2$``0E`*@`4``8'26$``!L!1@6('/X`@!
M````@RB@&(,X8!B`H,`!,D__Q(4HH!@0;__,@**`$)WCOZ!___^2D!``&'__
M]X4!````?__\6Z`0``B`HB```D``$("F(``"0``.`0```,).``"`H&```D``
M"I`0`!`3``!50`!@X9(28JB`I``($D@`!`$```!___U/D!``&('/X`@!````
MG>._F/`GH$3R)Z!(]">@3)`'H$22!Z!(0`!A#I0'H$P1``"PD!(A]!,``+"2
M$F"80``%`I00``E``&!_D!`@`,)*``"`H&``$D@`$P$```!``&!V`0````,`
M`+6`HB``$D@`!-`@8%A``&$,D!`@`4``8)4!````0`!@^9`0(`!``&!DT`(`
M`$``8-<!````P"H``$``8/*0$"``0`!@7=`"``!``&#Q`0```,(*``""$&`"
MPBH``$``8.F0$"``0`!@5-`"``!``&#H`0```,(*``""$&`!PBH``-`'H$20
M`B`%A!`@`(80``C$/[_XT1^_^)6@$0@#``!6T1A@H)6BB$@%``!6T1B@J(&J
MBL@=2``'`0```!$``%60$B*P$P``L4``8*V2$F`P0`!@L9$J(`(#``"UT"!@
M9,('H$C"`$``PB(```,``%6"$&*XPB(@!`,``%:"$&"XPB(@"`,``%6"$&+`
MPB(@#(00(`0#``"UQ"!@8,0'H$2`H*`!!$``%((0(`$7``"UEA+@8!D``+68
M$R!DQ`+``(0`0`*$`+__Q@,``(4HH`*)*&`"V@>@2,@#0`3((,`"@@!@`<0'
MH$2`H(`!-$__]<0"P``'``"UAA#@8,(`P`"$`(`!A`"__P,``+6"$&!DR`!`
M`(4HH`+`(0`"Q`#``-0'H$24`H`"!0``M=``H%@3``!4DA)B^)0"O__6`$``
M0`!?RI@0(`"`HB``$D@`!K`0``@#``"U0`!?XM``8%BP$``(`P``M4``8$30
M`&!8$0``57__^ZR0$B&X@*(@`!)(`!$#``"U`P``M=``8%R`HB``$D@`"0$`
M```1``!5?__[H9`2(<@#``"U@*(@``)(``30(&!<?___00$````#``"U0`!?
MH]``8%A``%_X`0```('/X`@!````G>.P`)P#OY#"`>`4PB>__((0(``1``!5
M?__[C)`2(<BD$``(`P``5N``8)20$``80`!@'I(0`!"`HB```D``!Q$``%60
M$B'X?__]5Y(0`!@0:`!]`0```$``7_F0$``8K!``"`,``%;H`&"8D!``&4``
M8!V2$``4@*(@``)``&ZB$``(*P``5:H580"L!:`!)S__^Z84X_BF!X`3+P``
M!#L``%6Z%V%P,P``/#D``"#"3$``@*!@`*-D0!6`I*```D``"Y`0`!)``&`]
MDA``$8"B(``22``&`0```$``8`*2$``4$&@`4:(0``A``%_4D!``$80$0`C&
M2+__Q$P``("@P`(20``,@A``")`$0`B"`'__P"H__\8*/_Z'*.`8ASC@&,1,
M``"`H,`"`D__^9`"/_^"!8`!@*!O_R1(``CP(Z!<$0``59`2(?A___T6DA``
M&!!H`#P!````D!``$Y(0(`&4$``7EA``'9@0`!%``&`$FA``$$``8`N0$"``
M0`!?=M`"``!``%_=`0```)00``B0$"`#0`!?3)(0`!.`HB``,D@`'I`0(`!`
M`%_^`0```$``7VG0`@``0`!?T`$```#"`B`0@@A`&8"@0!P22``3D!`@`)`0
M`!-``%]TDA`@`8"B(``R2``-D!`@`"$___N@%"/XH`>`$!$``%60$B'X?__\
MZ)(0`!!``%_RD!``$!!H``RP$``(0`!?LI(0`!2B$``(@*1@`#)/_Z+"3$``
M$0``59`2(?A___S:DA``&,0'O_S"`>`4A)B``8(0(``"2``$`0```$``7YP!
M````@<_@"`$````#/__?@A!BL)WC@`&H$``8P@'@%,(GO_R"$"``$0``57__
M^N^0$B'(@*(@``)```R@$``(PDH``("@8``"2``(`0```'___4\!````0`!?
MQY`0`!`0:`)$L!``"'___@\!````@*(@`!)(`">F$``(`S__WX(08TP1``!5
MD!(BR-`G@`&"!X`!!0``5800HM#$(&`$!0``5800H8#$(&`(PDH``("@8``"
M0`(W(3__WZ`4(TR@!X`0H`0@!'__^L@!````@*(@``)```:`I.``0`!?I@$`
M``"F$``(@*3@`#)```K"3,``T`0``,)*``"`H&``$D__\J`$(`00:`(C)P``
M5<),P`"`H&```D``$N`,P`!``%\7`0```((0`!.&$"!?H2P@&,0"``"A/"`7
MQ!"`$("(J``B2``"QBA``((`8`'$2$``@*"@`!)/__;@"$```S__WX(08R01
M``!5D!(B6-`G@`&"!X`!!0``5800HN#$(&`$!0``5800HNC$(&`(!0``5800
MHO#$(&`,!0``5800HOC$(&`0!0``5800H8#$(&`4PDH``("@8``"0`'X(3__
MWZ`4(R2@!X`0H`0@!*(0(`!___J%`0```("B(``"0``*I!``"'__^^P!````
M@*(@``)(``:`I&``0`!?7I`0`!*B$``(@*1@`!)``!D!````T`0``,)*``"`
MH&``$D__[:`$(`00:`'?`S__WW__^]J0$``0@*(@``)(``:`I&``0`!?3)`0
M`!"B$``(@*1@`!)```<!````X`2``,),``"`H&``$D__\J0$H`1``%[;D!``
M$:`0``A``%[8D!``$Z`$``B@!"0$0`!>\I`0`!"P$``(0`!>[Y`0`!"L$``(
M`P``5NX`8)0#``!5@A!BJ,(CH%SF(Z!@DA`@`900/_\7``!5EA+C`)@0`!%`
M`%\4FA``%Y`0`!9``%Y+DA`A[1$``%5___I`D!(A4("B(``B0``+X`4``$``
M7Q[@!0``DA``"'___J:0$``0@*(@`!)(``.@$``(X`4``$``7J^0$``0@*(@
M`P1(`".B$``(D`(__)`$``@3``!50`!?!Y(28Q"`HB``,D@`'*(0`!"`I&`$
M`D``!Z($`!'$3'_[PDW``("@@`$22``4HA``$.(%(`2`I&``(D``$*(0`!!`
M`%Z6D!``$8"B(`,H2``+HA``$)`"/_R0!$`($P``54``7NZ2$F,8@*(@``)(
M``,!````HA``$'__^A$!````@*(@`!)(`3(1``!5D!``$4``7LV2$"``@*(@
M``)(`2NX$``($S___Y(28_\5/___E!*C[D``7BB6$"`"(3__WZ`4(UB0$``<
MD@>`$$``7CV4$"`&P@^`$("@8``20``V@@>`$,((8`&`H&!#$D@`,Y`0`!R"
M!X`0P@A@`H"@8$$22``ODA`@`(('@!#""&`#@*!@0S)(`"N4$"``@@>`$,((
M8`2`H&!(,D@`)I00(`""!X`0P@A@!8"@8$4R2``AE!`@`)`0`!P3/___DA)C
M_Q4___^4$J/&0`!=_Y80(`(A/__?H!0C6*`'@!"0$``<DA``$$``7A.4$"`I
MX".@7`,``%6"$&&`PB.@8)`0`!B2$"`!E!`__Q<``%66$N,@F!``%D``7HZ:
M$``7$&@!&`$```"0$``<DA`@`)00(`!``%WEEA`@``,9T4B"$&,!PB>_6`,[
M\VJ"$&.)PB>_7`,F+K>"$&#^PB>_8`,$#)6"$&!VPB>_9`,P]+B"$&'PPB>_
M:,`GOVS`)[]PP">_M#L__]^Z%V-8N@>`'3<``""F![]TM!`@`!!H`$&J![]8
MQ`>_;(,L8`."`$`"@*"``0A(``6&$``1Q`>_<(0`H`'$)[]PPB>_;(,PX!W$
M![]P@@"``<(GOW#0![^T@*(@``)(`!.D$``=H!`@0*`D``B`I$`0H62`$9`$
MP`B2$``=0`!=_)00`!#"![^T@@0``8"@8$`22``BPB>_M*(D0!"D!T`0?__T
MOY`0`!6`I&`_!$``%I`0`!.@$``:J!``$9($@!!``%WKE!`@0'__]+60$``5
MH`0@0((D0!"`H&`_%$__^)`0`!.$!3_`A3"@!H(`H`&#*&`&I`2``:($?\"%
M**`&HB1``I(0`!*4$``10`!=HI80($3B)[^TD!``')(0`!U``%VCE!``&X"B
M(``43_^\HA``"$``7>F0$``<X@>_;.0'OW"#-&`#@@A@/X0'@`&&$#^`@@!@
M`8"@8#@$2``9QBB_=*`'OW20!``!DA`@`)00($!``%U_E"*``7__](B0![]8
MP"0``,`D(`3`)"`(P"0@#,`D(!#`)"`4P"0@&,`D(!S`)"`@P"0@),`D("C`
M)"`LP"0@,!!H``C`)"`TD`>_=)`"``&2$"``E!`@.$``76B4(H`!@S2@&,(O
MOZR#-*`0PB^_K8,TH`C"+[^NY"^_KX,T8!C"+[^P@S1@$,(OO[&#-&`(PB^_
MLN(OO[-___1CD`>_6,('OUB%,&`8Q"^_Z(4P8!#$+[_IA3!@",0OO^K"+[_K
MP@>_7(4P8!C$+[_LA3!@$,0OO^V%,&`(Q"^_[L(OO^_"![]@A3!@&,0OO_"%
M,&`0Q"^_\84P8`C$+[_RPB^_\\('OV2%,&`8Q"^_](4P8!#$+[_UA3!@",0O
MO_;"+[_WP@>_:(4P8!C$+[_XA3!@$,0OO_F%,&`(Q"^_^L(OO_NB![^XH!`@
M`*0'O^@G``!5IA3C,)`0`!&2$"`!E!`__Y80`!-``%V[V`R`$*`$(`&`I"`4
M$D__^*($8`+`+[_@@@>_N,(CH%P#``!5@A!A@,(CH&"0$``8DA`@`900/_\7
M``!5EA+C()@0`!9``%VIFA``%Q!H`#,!````$0``59`2(.`3``!5?__ZJY(2
M8J!``%S7HA``&-`CH%P#``!5@A!A@,(CH&"0$``8DA`@`900/_\7``!5EA+C
M.)@0`!9``%V4FA``%Z`0(``E``!5I!2A@"<``%40:``.IA3C2$``7,.@!"`!
MT".@7.`CH&#D(Z!DD!``$9(0(`&4$#__EA``$Y@0`!9``%V"FA``%Y`0`!A`
M`%RYDA`A[8"B/_\20``(`0```$``7*L!````P@(``("@8!$"3__J`0```$``
M7/:0$``6$0``59`2(<A___IYDA``&'__^PF0$``8Q`>__,(!X!2$F(`!@A`@
M``)(`"(!````$&@`'@$````G``!5$&_]\Z84XV"B$"```S__WX(08SPA``!5
MH!0C:.`G@`&"!X`!!0``5800HW#$(&`$!0``5800H0#$(&`(!0``5800H8#$
M(&`,PDP``"4__]^D%*,\I`>`$H"@8``23_X0I`2@!!!O_AX!````0`!=&P$`
M``"!S^`(`0```)WCOZ!``%U,D!`@`$``7+?0`@``0`!<S0$```""$"`!PBH`
M`!$``%5___ALD!(AJ("B(``"0``*`0```,)*``"`H&`Q$D@`!@$```#"2B`!
M@*!@``)(``0!````?__[%`$```!``%TTD!`@`$``7)_0`@``$P``59(28WB4
M$"`!0`!<BY80(`N`HB```D``2J`0(`#"`B`,[`!@&`,``+7"`&!@I!`@!"D`
M`+6H%2!D*P``M8"@8`$$0``JJA5@8$``71V0$"``0`!<B-`"``"2$``6E!``
M$$``7,R6$"``@*(@``)``!^B$``(P@4``.8`0!+"`@``Q`!@"("(I``"0``$
M`0```!!H``O2`&`,0`!="9`0(`!``%QTT`(``-($0`"4$"``0`!=&Y80(`*2
M$``(0`!=!I`0`!.`HB``$D``"0,``+6@!"`!@@0@`<0%0`"`H(`!%$__VJ0$
MH`0#``"UP@!@8(0`?_^`H(`0$D@`$8"@8`$$0``/H!`@`2,``+6B%&!@0`!<
MZY`0(`!``%Q6T`(``$``7$*2$``6H`0@`<($0`"`H$`0%$__]P$```!``%S@
MD!`@`$``7$O0`@``$P``59(28X"4$"`!0`!<-Y80(`6`HB```D``&:`0``A`
M`%S4D!`@`$``7#_0`@``P@0@#-(`0``5``!50`!<,902HXC"!"`,P@!``,0`
M8`@#`!``@(B``0)(``D!````0`!<Q)`0(`!``%POT`(``,($(`Q``%R&T@!`
M`$``7+V0$"``0`!<*-`"```3``!5DA)CD)00(`%``%P4EA`@!8"B(``"0``<
MH!``"!$``%5___?9D!(A^("B(``"0``,HA``"$``7*N0$"``0`!<%M`"``#"
M!"`,T@!``$``7`F4$``1$&@`#`$```!``%RAD!`@`$``7`S0`@``Q`0@#`,`
M`+7"`&!DT@"``'__]_G4`$``0`!<EY`0(`!``%P"T`(``$``7!@!````P"H`
M`$``7)"0$"``0`!;^]`"``!``%R5`0```,`B```1``!5?__WL9`2(<@#``"U
M@*(@`!)(`#70(&!<`P``M7___+/0`&!D`P``M=`@8%S"!"`,P@!``,0`8`B`
MB*0``D``!`$````0:``+T`!@#$``7'60$"``0`!;X-`"``#"!"`,T@!``)00
M(`!``%R&EA`@`B,``+6B%&!D0`!<#=($0`#"!$``X@!``,($(`S"`$``Q`!@
M"("(I``"0``$I!``"!!H``S4`&`,0`!<7I`0(`!``%O)T`(``,($(`S2`$``
ME!`@`$``7&^6$"`"E!``"!$``%60$B.8DA``$4``7#"6$``20`!;@)(0(>V`
MH``(A$`@`((:(!&`H``!@D`@`("(@`$"0``,EA``"("B/_\"2``)`P``M<(`
M8&01``!5D!(CR-(`0``#``"U0`!<'-0`8%R!S^`(`0```)WCOZ!``%PXD!`@
M`$``6Z/0`@``$P``5I(28!@5``"PE!*AZ!<``%9``%PIEA+@.('/X`@!````
MG>._H$``7"J0$"``0`!;E=`"``!____M`0```$``7"20$"``0`!;C]`"```3
M``!6DA)@2!4``%.4$J)P%P``5982X8"8$``+0`!;L)H0(`"!S^`(`0``````
M``````````````````"!P^`(K@/`%S!H``8!`````0````$````!`````0``
M`)WCOZ`#````+P``6W____6N!>!T@A!@",(%P`&`H&```D```[80(`#V`$``
M$(!;4('H```!`````0````$```"!P^`(`0```('#X`BN`\`7,&@`!`$````!
M`````0```)WCOZ`O``!;?___^*X%X!A``%O_`0````4````#````@A!@$(00
MH`SB!<`!Y`7``J0D@!&#/*`?@8!@`*3\H`0"0``+H!`@`,($0`"0$``8DA``
M&900`!J?P$``H`0@`8"D`!(*3__YH@1@!('/X`@!````,&@``P$````!````
MG>._H"$``*^@%"+XP@0__("@?_\"0``(H`0__)_`0`"@!#_\P@0``("@?_\2
M3__\`0```('/X`@!`````0```)WCOZ"!S^`(`0```#!H``4!`````0````$`
M```!````G>._H'__\<\!````@<?@"('H``````````(``0````!005)?0TQ%
M04X`````````+W!R;V,O<V5L9B]E>&4``"X`````````+BX````````E<R\E
M<P```"]P<F]C+R5I+R5S``````!E>&4``````$Q$7TQ)0E)!4EE?4$%42`!,
M24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42```````
M```E<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4````
M``````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````
M4$%27U1%35```````````%!!4E]$14)51P````````!005)?0T%#2$4`````
M````4$%27U!23T=.04U%`````%!!4E]!4D=#``````````!005)?05)'5E\P
M````````4$%27T=,3T)!3%]$14)51P``````````4$%27T=,3T)!3%]435!$
M25(`````````4$%27U1-4$1)4@```````%!!4E]'3$]"04Q?5$5-4`!005)?
M1TQ/0D%,7T-,14%.``````````!005)?0TQ%04X]````````,0````````!P
M87(M`````"5S````````+64````````M+0```````%5315(`````55-%4DY!
M344``````````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````)7,E
M<R5S)7,``````````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``
M)3`R>``````E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````
M````4UE35$5-``!#.EQ414U0`"]T;7``````05)'5@`````8`````````'!E
M<FP`````,``````````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B
M;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP
M;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@
M)6DN"@```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````<&5R;'AS
M:2YC`````````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"\`````````.@``
M``````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(````````5A@
M``%8:````````````````$'/____@```<&%R+G!L```C(2]U<W(O8FEN+W!E
M<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A
M8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U
M<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I
M8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U
M:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@
M("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E
M;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@
M<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H
M(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*
M("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@
M("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T
M96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY
M(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG
M('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T
M:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@
M("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E
M<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@
M86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S
M<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S
M('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@
M("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@
M("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^
M(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A
M<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@
M("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@
M("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C
M;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@
M("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@
M("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R
M9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE
M*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V
M86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!
M4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M
M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@
M+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@
M(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF
M("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%4
M2`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@
M("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I
M.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N
M9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*
M>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#
M:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM[
M"B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I
M;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R
M.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F
M(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@
M<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K
M*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D
M9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%
M>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R
M97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]
M("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T
M96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@
M("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@
M86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@
M<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY
M("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*
M("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@
M("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A
M.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN
M="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F
M=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F
M+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@
M("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*
M("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R
M97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D
M:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I
M('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O
M.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF
M(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@
M("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92([
M"@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE
M+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H
M)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT[
M"B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T
M=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M
M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@
M("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O
M=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O
M=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\
M)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D[
M"B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE
M(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L
M960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@
M<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@
M4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP
M97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*
M"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@
M(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*
M("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@
M("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!
M8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@
M("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@
M("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T
M(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*
M(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM0
M05)?1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP
M:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@
M8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U
M("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@
M('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I
M;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'
M4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE
M(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE
M"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA
M;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6
M.PH@("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@
M("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*
M("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*
M("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@
M("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D
M,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G
M*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@
M("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D
M<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@
M("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC
M*"D["B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@
M("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*
M(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O
M=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@
M24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]
M"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*
M("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@
M("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`]
M(&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T
M<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F
M:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D
M:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@
M9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@
M(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@
M("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L
M"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@
M("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H
M9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@
M<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@
M+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N
M=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@
M)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]0
M05)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@
M<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G
M("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G
M.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD
M968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[
M>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@
M("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I
M.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T
M:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@
M("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H
M)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.
M0SL*"B`@("`@("`@:68@*"1#;VYF:6=[7V1E;&EM?2!E<2`G7%PG*2![('-[
M7%Q]>R]]9R!F;W(@0&EN8R!]"@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S
M="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO
M;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:
M;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I
M9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@
M("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@
M=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F
M86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@
M+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*
M"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL
M92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D
M,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@
M(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@
M("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@
M("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I
M9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X[
M"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@
M("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O
M+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@
M("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R
M+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)
M3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F
M*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@
M("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H
M92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S
M=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]
M"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W
M-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E
M<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O
M9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T
M(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@
M)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@
M("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@
M("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]
M"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO
M=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50
M871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y
M;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T
M<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,[
M"B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@
M("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,[
M"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@
M("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@
M("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV
M93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@
M("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O
M9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L
M<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N
M=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@
M("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@
M("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@
M("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED
M.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@
M(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@
M("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@
M("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@
M("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@
M+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q
M.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@
M("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@
M("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@
M86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@
M("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D
M8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@
M('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*
M("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@
M;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I
M.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N
M86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D
M9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N
M9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@
M(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM
M;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A
M;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G
M;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O
M9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@
M("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%
M3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*
M("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE
M?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@
M)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF
M("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@
M("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@
M("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P
M=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D
M96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B![
M"B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@
M("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@
M("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@
M("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE
M=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@
M)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@
M("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%2
M7T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N
M(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D
M;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@
M(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#
M;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI
M8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C
M=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G
M;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S
M<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$R
M"@I?7T5.1%]?"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#_____`````/____\```````````````$````!````
M`0```K(````!```"O0````$```+'`````0```Q8````!```$9`````P``1MD
M````#0`!5,`````$``$!C&___O4``03D````!0`!#^@````&``$(N`````H`
M``7]````"P```!`````5``````````,``L`4`````@```\P````4````!P``
M`!<``1>0````!P`!%VP````(```#\`````D````,;____@`!%LQO____````
M`F____```17F````````````````````````````````````````````````
M``````````````````*_"````````L08``*^]``"OO0`````````````````
M```````````````````````````````````````````````#```P,+__\P$`
M```#```\,+__\`$````#``!(,+__[0$````#``!4,+__Z@$````#``!@,+__
MYP$````#``!L,+__Y`$````#``!X,+__X0$````#``"$,+__W@$````#``"0
M,+__VP$````#``"<,+__V`$````#``"H,+__U0$````#``"T,+__T@$````#
M``#`,+__SP$````#``#,,+__S`$````#``#8,+__R0$````#``#D,+__Q@$`
M```#``#P,+__PP$````#``#\,+__P`$````#``$(,+__O0$````#``$4,+__
MN@$````#``$@,+__MP$````#``$L,+__M`$````#``$X,+__L0$````#``%$
M,+__K@$````#``%0,+__JP$````#``%<,+__J`$````#``%H,+__I0$````#
M``%T,+__H@$````#``&`,+__GP$````#``&,,+__G`$````#``&8,+__F0$`
M```#``&D,+__E@$````#``&P,+__DP$````#``&\,+__D`$````#``'(,+__
MC0$````#``'4,+__B@$````#``'@,+__AP$````#``'L,+__A`$````#``'X
M,+__@0$````#``($,+__?@$````#``(0,+__>P$````#``(<,+__>`$````#
M``(H,+__=0$````#``(T,+__<@$````#``)`,+__;P$````#``),,+__;`$`
M```#``)8,+__:0$````#``)D,+__9@$````#``)P,+__8P$````#``)\,+__
M8`$````#``*(,+__70$````#``*4,+__6@$````#``*@,+__5P$````#``*L
M,+__5`$````#``*X,+__40$````#``+$,+__3@$````#``+0,+__2P$````#
M``+<,+__2`$````#``+H,+__10$````#``+T,+__0@$````#``,`,+__/P$`
M```#``,,,+__/`$````#``,8,+__.0$````#``,D,+__-@$````#``,P,+__
M,P$````#``,\,+__,`$````#``-(,+__+0$````#``-4,+__*@$````#``-@
M,+__)P$````#``-L,+__)`$````#``-X,+__(0$````#``.$,+__'@$````#
M``.0,+__&P$````#``.<,+__&`$````#``.H,+__%0$````#``.T,+__$@$`
M```#``/`,+__#P$````#``/,,+__#`$````#``/8,+__"0$````#``/D,+__
M!@$````#``/P,+__`P$````!``````````````#_____``%8L```6]E'0T,Z
M("A58G5N='4@-"XT+C(M.75B=6YT=30I(#0N-"XS(#(P,3`P,3$V("AP<F5R
M96QE87-E*0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N8W1O<G,`+F1T
M;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````
M```````````````````````````````````````````````````````+````
M`0````(``0$T```!-````!,```````````````$`````````$P````<````"
M``$!2````4@````@```````````````$`````````"$````'`````@`!`6@`
M``%H````)```````````````!``````````X````!0````(``0&,```!C```
M`U@````&``````````0````$````-&____8````"``$$Y```!.0```/4````
M!@`````````$````!````#X````+`````@`!"+@```BX```',`````<````!
M````!````!````!&`````P````(``0_H```/Z```!?T```````````````$`
M````````3F____\````"``$5Y@``%>8```#F````!@`````````"`````@``
M`%MO___^`````@`!%LP``!;,````H`````<````"````!`````````!J````
M!`````(``1=L```7;````"0````&``````````0````,````=`````0````"
M``$7D```%Y````/,````!@```!8````$````#````'X````!````!@`!&UP`
M`!M<````4```````````````!`````````"$`````0````8``1O````;P```
M.0```````````````"``````````B@````$````&``%4P```5,`````4````
M```````````$`````````)`````!`````@`!5-@``%38``!?P```````````
M````"`````````"8`````0````(``;28``"TF`````0```````````````0`
M````````H@````$````#``*^]```OO0````(```````````````$````````
M`*D````!`````P`"OOP``+[\````"```````````````!`````````"P````
M`0````,``K\$``"_!`````0```````````````0`````````M0````8````#
M``*_"```OP@```#X````!P`````````$````"````+X````!`````P`"P```
M`,``````%```````````````!`````0```!Y`````0````<``L`4``#`%```
M!`````````````````0`````````PP````$````#``+$%```Q!0````4````
M```````````$`````````,D````(`````P`"Q"@``,0H```00```````````
M````"`````````#.`````0```#````````#$*````#D```````````````$`
K```!`````0````,`````````````Q&$```#7```````````````!````````
